==> ZenTaoPMS-max6.2-php7.2_7.4.zip: zentaopms/module/projectbuild/lang/zh-tw.php <==
<?php
/**
 * The project build module zh-tw file of ZenTaoPMS.
 *
 * @copyright   Copyright 2009-2023 禪道軟件（青島）有限公司(ZenTao Software (Qingdao) Co., Ltd. www.cnezsoft.com)
 * @license     ZPL(http://zpl.pub/page/zplv12.html) or AGPL(https://www.gnu.org/licenses/agpl-3.0.en.html)
 * @author      Yuchun Li <liyuchun@cnezsoft.com>
 * @package     projectrelease
 * @version     $Id: zh-tw.php 4129 2020-11-27 01:58:14Z wwccss $
 * @link        https://www.zentao.net
 */
$lang->projectbuild->common           = $lang->projectCommon . '構建';
$lang->projectbuild->browse           = '構建列表';
$lang->projectbuild->create           = "創建構建";
$lang->projectbuild->edit             = "編輯構建";
$lang->projectbuild->delete           = "刪除構建";
$lang->projectbuild->view             = "構建詳情";
$lang->projectbuild->linkStory        = "關聯{$lang->SRCommon}";
$lang->projectbuild->linkBug          = "關聯Bug";
$lang->projectbuild->unlinkStory      = "移除{$lang->SRCommon}";
$lang->projectbuild->unlinkBug        = "移除Bug";
$lang->projectbuild->batchUnlink      = '批量移除';
$lang->projectbuild->batchUnlinkStory = "批量移除{$lang->SRCommon}";
$lang->projectbuild->batchUnlinkBug   = '批量移除Bug';
$lang->projectbuild->name             = '名稱編號';
$lang->projectbuild->execution        = $lang->executionCommon;
$lang->projectbuild->product          = '所屬' . $lang->productCommon;
$lang->projectbuild->scmPath          = '原始碼地址';
$lang->projectbuild->filePath         = '下載地址';
$lang->projectbuild->desc             = '描述';
$lang->projectbuild->systemName       = '所屬應用';

==> ZenTaoPMS-max7.2-php7.1.zip: zentaopms/module/projectbuild/lang/zh-tw.php <==
<?php
/**
 * The project build module zh-tw file of ZenTaoPMS.
 *
 * @copyright   Copyright 2009-2023 禪道軟件（青島）有限公司(ZenTao Software (Qingdao) Co., Ltd. www.cnezsoft.com)
 * @license     ZPL(http://zpl.pub/page/zplv12.html) or AGPL(https://www.gnu.org/licenses/agpl-3.0.en.html)
 * @author      Yuchun Li <liyuchun@cnezsoft.com>
 * @package     projectrelease
 * @version     $Id: zh-tw.php 4129 2020-11-27 01:58:14Z wwccss $
 * @link        https://www.zentao.net
 */
$lang->projectbuild->common           = $lang->projectCommon . '構建';
$lang->projectbuild->browse           = '構建列表';
$lang->projectbuild->create           = "創建構建";
$lang->projectbuild->edit             = "編輯構建";
$lang->projectbuild->delete           = "刪除構建";
$lang->projectbuild->view             = "構建詳情";
$lang->projectbuild->linkStory        = "關聯{$lang->SRCommon}";
$lang->projectbuild->linkBug          = "關聯Bug";
$lang->projectbuild->unlinkStory      = "移除{$lang->SRCommon}";
$lang->projectbuild->unlinkBug        = "移除Bug";
$lang->projectbuild->batchUnlink      = '批量移除';
$lang->projectbuild->batchUnlinkStory = "批量移除{$lang->SRCommon}";
$lang->projectbuild->batchUnlinkBug   = '批量移除Bug';
$lang->projectbuild->name             = '名稱編號';
$lang->projectbuild->execution        = $lang->executionCommon;
$lang->projectbuild->product          = '所屬' . $lang->productCommon;
$lang->projectbuild->scmPath          = '原始碼地址';
$lang->projectbuild->filePath         = '下載地址';
$lang->projectbuild->desc             = '描述';
$lang->projectbuild->systemName       = '所屬' . $lang->product->system;
$lang->projectbuild->system           = '所屬' . $lang->product->system;
